@@ -198,6 +198,16 @@ def update_model(nomitall_url, nomitall_secret, model, model_type, org, channel)
             "POST", f"engine/deploy/{org}", params={"channel": channel}, json=model
         )
 
+    elif model_type == "shared_config_type":
+        _logger.info("Pushing shared config type to nomitall")
+        resp = session.request("POST", "shared_config_type/update", json=model)
+        check_response(resp)
+
+    elif model_type == "shared_field_type":
+        _logger.info("Pushing shared field type to nomitall")
+        resp = session.request("POST", "shared_field_type/update", json=model)
+        check_response(resp)
+
     elif model_type == "shared_object_type":
         _logger.info("Pushing shared object type to nomitall")
         session.request("POST", "shared_object_type/update", json=model)
