@@ -19,6 +19,9 @@ parameter_types = [
     "string",
     "enum",
     "enum_list",
+    "date",
+    "datetime",
+    "time",
 ]
 help_schema = {
     "oneof_schema": [
